@@ -43,3 +43,17 @@ for(myKernel in KERNELS) {
   print(myacp)
 } 
 
+x = matrix (1:12, 3, 4)
+ncol = as.integer(dim(x)[2])
+nrow = as.integer(dim(x)[1])
+rien = .C("checkMatrix",as.double(x), nrow, ncol, PACKAGE="amap")
+
+m = matrix(1:16,4,4)
+d = as.dist(m)
+rien = .C("checkMatrixTriangle",as.double(d),as.integer(4), as.integer(0))
+
+d=c(1,2,3,4,6,7,8,11,12,16)
+rien = .C("checkMatrixTriangle",as.double(d),as.integer(4), as.integer(1))
+
+
+
